# entsopy

  

Your cli tool for **download data from the** from ENTSO-E transparency platform.


**Please note that a security token is mandatory for accessing the ENTSO-E API service.**

## Requirements
Python 3.11+

## Installation
```
$ pip install entsopy
```
Check out the latest entsopy version on pypi: [pypi.org/project/entsopy](https://pypi.org/project/entsopy/)

## Commands

 - **`entsopy start` for **starting** the cli app;**
 - **`entsopy reset` for resetting entsopy configuration;**
 - **`entsopy log` for manage entsopy logs;**
 - **`entsopy --help` for seeing the helper.**

  

## Useful links

-  **Ensto-e official website:** https://www.entsoe.eu/

-  **Ensto-e transparency platform:** https://transparency.entsoe.eu/

-  **Ensto-e security token:** https://transparency.entsoe.eu/content/static_content/Static%20content/web%20api/Guide.html#_authentication_and_authorisation

  
## License

This project is licensed under the terms of the MIT license.

  
## Founding

> Entsopy was funded by the European Union - _NextGenerationEU_, in the framework of the _GRINS - Growing
> Resilient, INclusive and Sustainable_ project (GRINS PE00000018 – CUP C93C22005270001)